==> nw-style-guide-15.1.0.tgz: package/charts/axis/axis-base.js <==
import { Input, Directive } from "@angular/core";
import { ChartUtils } from "../chart.utils";
import { select } from "d3-selection";
import * as i0 from "@angular/core";
import * as i1 from "../chart.component";
import * as i2 from "../chart.utils";
export class AxisBase {
    constructor(_elRef, chart, _chartUtils) {
        this._elRef = _elRef;
        this.chart = chart;
        this._chartUtils = _chartUtils;
        this.tickSizeOuter = 6;
        this.showGuidlines = false;
        this.animDuration = ChartUtils.ANIMATION_DURATION;
        this.easing = ChartUtils.ANIMATION_EASING;
        this.label = '';
    }
    ngOnInit() {
        this.axisSelection = select(this._elRef.nativeElement);
        this.createAxis();
        this.setDomain();
        this.setTicks();
        this.createLabel();
        this.render();
        this._subscribeToChartResize();
    }
    ngOnChanges(c) {
        const isDomainChange = ChartUtils.hasInputChanged(c.domain);
        const isTickSettingsChange = ChartUtils.hasInputChanged(c.tickCount) ||
            ChartUtils.hasInputChanged(c.tickSizeOuter) ||
            ChartUtils.hasInputChanged(c.showGuidlines) ||
            ChartUtils.hasInputChanged(c.tickValues);
        if (isDomainChange || isTickSettingsChange) {
            this.setDomain();
            this.setTicks();
            this.update();
        }
    }
    createAxis() {
        throw new Error("Method not implemented.");
    }
    setTicks() {
        this.axis
            .ticks(this.tickCount)
            .tickFormat(this.tickFormat)
            .tickSizeOuter(this.tickSizeOuter);
        if (this.tickValues) {
            this.axis.tickValues(this.tickValues);
        }
    }
    setDomain() {
        throw new Error("Method not implemented.");
    }
    createLabel() {
        this.axisLabelSelection = this.chart.svg.append('text')
            .style('text-anchor', 'middle');
    }
    render() {
        throw new Error("Method not implemented.");
    }
    update() {
        this.axisSelection
            .transition()
            .duration(this.animDuration)
            .ease(this.easing)
            .call(this.axis);
    }
    get fullWidth() {
        return this.chart.width + this.chart.margins.left + this.chart.margins.right;
    }
    get fullHeight() {
        return this.chart.height + this.chart.margins.top + this.chart.margins.bottom;
    }
    _subscribeToChartResize() {
        this._chartResizeSub = this._chartUtils.chartResize$
            .subscribe(_ => {
            this.setDomain();
            this.setTicks();
            this.render();
        });
    }
    ngOnDestroy() {
        this._chartResizeSub.unsubscribe();
    }
}
AxisBase.ɵfac = function AxisBase_Factory(t) { return new (t || AxisBase)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i1.ChartComponent), i0.ɵɵdirectiveInject(i2.ChartUtils)); };
AxisBase.ɵdir = /*@__PURE__*/ i0.ɵɵdefineDirective({ type: AxisBase, inputs: { tickFormat: "tickFormat", tickCount: "tickCount", tickSizeOuter: "tickSizeOuter", tickValues: "tickValues", showGuidlines: "showGuidlines", animDuration: "animDuration", easing: "easing", label: "label" }, features: [i0.ɵɵNgOnChangesFeature] });
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(AxisBase, [{
        type: Directive
    }], () => [{ type: i0.ElementRef }, { type: i1.ChartComponent }, { type: i2.ChartUtils }], { tickFormat: [{
            type: Input
        }], tickCount: [{
            type: Input
        }], tickSizeOuter: [{
            type: Input
        }], tickValues: [{
            type: Input
        }], showGuidlines: [{
            type: Input
        }], animDuration: [{
            type: Input
        }], easing: [{
            type: Input
        }], label: [{
            type: Input
        }] }); })();

==> nw-style-guide-16.1.0.tgz: package/charts/axis/axis-base.js <==
import { Input, Directive } from "@angular/core";
import { ChartUtils } from "../chart.utils";
import { select } from "d3-selection";
import * as i0 from "@angular/core";
import * as i1 from "../chart.component";
import * as i2 from "../chart.utils";
export class AxisBase {
    constructor(_elRef, chart, _chartUtils) {
        this._elRef = _elRef;
        this.chart = chart;
        this._chartUtils = _chartUtils;
        this.tickSizeOuter = 6;
        this.showGuidlines = false;
        this.animDuration = ChartUtils.ANIMATION_DURATION;
        this.easing = ChartUtils.ANIMATION_EASING;
        this.label = '';
    }
    ngOnInit() {
        this.axisSelection = select(this._elRef.nativeElement);
        this.createAxis();
        this.setDomain();
        this.setTicks();
        this.createLabel();
        this.render();
        this._subscribeToChartResize();
    }
    ngOnChanges(c) {
        const isDomainChange = ChartUtils.hasInputChanged(c.domain);
        const isTickSettingsChange = ChartUtils.hasInputChanged(c.tickCount) ||
            ChartUtils.hasInputChanged(c.tickSizeOuter) ||
            ChartUtils.hasInputChanged(c.showGuidlines) ||
            ChartUtils.hasInputChanged(c.tickValues);
        if (isDomainChange || isTickSettingsChange) {
            this.setDomain();
            this.setTicks();
            this.update();
        }
    }
    createAxis() {
        throw new Error("Method not implemented.");
    }
    setTicks() {
        this.axis
            .ticks(this.tickCount)
            .tickFormat(this.tickFormat)
            .tickSizeOuter(this.tickSizeOuter)
            .tickValues(this.tickValues);
    }
    setDomain() {
        throw new Error("Method not implemented.");
    }
    createLabel() {
        this.axisLabelSelection = this.chart.svg.append('text')
            .style('text-anchor', 'middle');
    }
    render() {
        throw new Error("Method not implemented.");
    }
    update() {
        this.axisSelection
            .transition()
            .duration(this.animDuration)
            .ease(this.easing)
            .call(this.axis);
    }
    get fullWidth() {
        return this.chart.width + this.chart.margins.left + this.chart.margins.right;
    }
    get fullHeight() {
        return this.chart.height + this.chart.margins.top + this.chart.margins.bottom;
    }
    _subscribeToChartResize() {
        this._chartResizeSub = this._chartUtils.chartResize$
            .subscribe(_ => {
            this.setDomain();
            this.setTicks();
            this.render();
        });
    }
    ngOnDestroy() {
        this._chartResizeSub.unsubscribe();
    }
}
AxisBase.ɵfac = function AxisBase_Factory(t) { return new (t || AxisBase)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i1.ChartComponent), i0.ɵɵdirectiveInject(i2.ChartUtils)); };
AxisBase.ɵdir = /*@__PURE__*/ i0.ɵɵdefineDirective({ type: AxisBase, inputs: { tickFormat: "tickFormat", tickCount: "tickCount", tickSizeOuter: "tickSizeOuter", tickValues: "tickValues", showGuidlines: "showGuidlines", animDuration: "animDuration", easing: "easing", label: "label" }, features: [i0.ɵɵNgOnChangesFeature] });
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(AxisBase, [{
        type: Directive
    }], () => [{ type: i0.ElementRef }, { type: i1.ChartComponent }, { type: i2.ChartUtils }], { tickFormat: [{
            type: Input
        }], tickCount: [{
            type: Input
        }], tickSizeOuter: [{
            type: Input
        }], tickValues: [{
            type: Input
        }], showGuidlines: [{
            type: Input
        }], animDuration: [{
            type: Input
        }], easing: [{
            type: Input
        }], label: [{
            type: Input
        }] }); })();
